/* 
 * Copyright (c) 2010, 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#import <Cocoa/Cocoa.h>

#import "ScintillaView.h"
#import "Scintilla.h"
#include "sqlide/sql_editor_be.h"

@class MScintillaView;

@interface NSObject(MScintillaViewDelegate)
- (void)scintillaViewFindPanelClose:(MScintillaView*)editor;
@end


@interface MScintillaView : ScintillaView 
{
  IBOutlet NSView *mFindPanel;
  IBOutlet NSSegmentedControl *mFindTypeSegmented;
  IBOutlet NSTextField *mFindText;
  IBOutlet NSTextField *mReplaceText;
  IBOutlet NSTextField *mFindLabel;
  IBOutlet NSSegmentedControl *mFindSegmented;
  Sql_editor::Ref mBackEnd;
  BOOL mIgnoreCase;
  BOOL mMatchWhole;
  BOOL mWrapAround;
  
  id delegate;
}

- (void)setEditorBackEnd:(const Sql_editor::Ref&)be;

- (NSView*)embedableFindPanel;
- (void)focusFindPanel;
- (void)enableReplaceInFindPanel: (BOOL)flag;

- (IBAction)findActionClicked:(id)sender;

- (void)setShowsSpecialCharacters:(BOOL)flag;

- (id)delegate;

@end
